==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebCardDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardDescription } from "./WebCardDescription";
/**
 * @hidden
 */
export let WebCardDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCardDescriptionMetadata extends Base {
        static b(a) {
            if (WebCardDescriptionMetadata.a == null) {
                WebCardDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCardDescriptionMetadata.c(WebCardDescriptionMetadata.a);
            }
            if (a.k(WebCardDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebCardDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Card");
            a.item("__tagNameWC", "String:igc-card");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Elevated", "Boolean");
        }
        static d(a) {
            WebCardDescriptionMetadata.b(a);
            a.ad("WebCard", () => new WebCardDescription());
            a.ac("WebCard", WebCardDescriptionMetadata.a);
        }
    }
    WebCardDescriptionMetadata.$t = markType(WebCardDescriptionMetadata, 'WebCardDescriptionMetadata');
    WebCardDescriptionMetadata.a = null;
    return WebCardDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebCardDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardDescription } from "./WebCardDescription";
/**
 * @hidden
 */
export let WebCardDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCardDescriptionMetadata extends Base {
        static b(a) {
            if (WebCardDescriptionMetadata.a == null) {
                WebCardDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCardDescriptionMetadata.c(WebCardDescriptionMetadata.a);
            }
            if (a.k(WebCardDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCardDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Card");
            a.item("__tagNameWC", "String:igc-card");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Elevated", "Boolean");
        }
        static d(a) {
            WebCardDescriptionMetadata.b(a);
            a.ae("WebCard", () => new WebCardDescription());
            a.ad("WebCard", WebCardDescriptionMetadata.a);
        }
    }
    WebCardDescriptionMetadata.$t = markType(WebCardDescriptionMetadata, 'WebCardDescriptionMetadata');
    WebCardDescriptionMetadata.a = null;
    return WebCardDescriptionMetadata;
})();
